# dict-from-pypinyin

[![PyPI](https://img.shields.io/pypi/v/dict-from-pypinyin.svg)](https://pypi.python.org/pypi/dict-from-pypinyin)
[![PyPI](https://img.shields.io/pypi/pyversions/dict-from-pypinyin.svg)](https://pypi.python.org/pypi/dict-from-pypinyin)
[![MIT](https://img.shields.io/github/license/stefantaubert/dict-from-pypinyin.svg)](https://github.com/stefantaubert/dict-from-pypinyin/blob/master/LICENSE)
[![PyPI](https://img.shields.io/pypi/wheel/dict-from-pypinyin.svg)](https://pypi.python.org/pypi/dict-from-pypinyin)
[![PyPI](https://img.shields.io/pypi/implementation/dict-from-pypinyin.svg)](https://pypi.python.org/pypi/dict-from-pypinyin)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.7524283.svg)](https://doi.org/10.5281/zenodo.7524283)

Command-line interface (CLI) to create a pronunciation dictionary by looking up pinyin transcriptions using [pypinyin](https://github.com/mozillazg/python-pinyin) including the possibility of ignoring punctuation and splitting words on hyphens before transcribing them.

## Installation

```sh
pip install dict-from-pypinyin --user
```

## Usage

```sh
dict-from-pypinyin-cli
```

### Example

```sh
# Create example vocabulary
cat > /tmp/vocabulary.txt << EOF
社会语言学？
㐻，
『㑐
鲜-亮。
『占斌？
『机具-机呀？
EOF

# Create dictionary from vocabulary
dict-from-pypinyin-cli \
  /tmp/vocabulary.txt \
  /tmp/result.dict \
  --split-on-hyphen

cat /tmp/result.dict
```

Output:

```txt
社会语言学？  shè huì yǔ yán xué ？
社会语言学？  shè huì yǔ yàn xué ？
社会语言学？  shè huì yǔ yín xué ？
社会语言学？  shè huì yù yán xué ？
社会语言学？  shè huì yù yàn xué ？
社会语言学？  shè huì yù yín xué ？
社会语言学？  shè kuài yǔ yán xué ？
社会语言学？  shè kuài yǔ yàn xué ？
社会语言学？  shè kuài yǔ yín xué ？
社会语言学？  shè kuài yù yán xué ？
社会语言学？  shè kuài yù yàn xué ？
社会语言学？  shè kuài yù yín xué ？
㐻，  nèi ，
『㑐  『 shū
鲜-亮。  xiān - liàng 。
鲜-亮。  xiān - liáng 。
鲜-亮。  xiǎn - liàng 。
鲜-亮。  xiǎn - liáng 。
『占斌？  『 zhàn bīn ？
『占斌？  『 zhān bīn ？
『占斌？  『 tiē bīn ？
『机具-机呀？  『 jī jù - jī ya ？
『机具-机呀？  『 jī jù - jī yā ？
『机具-机呀？  『 jī jù - jī xiā ？
『机具-机呀？  『 jī jù - wèi ya ？
『机具-机呀？  『 jī jù - wèi yā ？
『机具-机呀？  『 jī jù - wèi xiā ？
『机具-机呀？  『 wèi jù - jī ya ？
『机具-机呀？  『 wèi jù - jī yā ？
『机具-机呀？  『 wèi jù - jī xiā ？
『机具-机呀？  『 wèi jù - wèi ya ？
『机具-机呀？  『 wèi jù - wèi yā ？
『机具-机呀？  『 wèi jù - wèi xiā ？
```

## Dependencies

- `pronunciation-dictionary >= 0.0.5`
- `word-to-pronunciation >= 0.0.1`
- `ordered-set >= 4.1.0`
- `pypinyin >= 0.47.1, < 0.48`
- `tqdm`

## License

MIT License

## Acknowledgments

[pypinyin](https://github.com/mozillazg/python-pinyin)

Funded by the Deutsche Forschungsgemeinschaft (DFG, German Research Foundation) – Project-ID 416228727 – CRC 1410

## Citation

If you want to cite this repo, you can use this BibTeX-entry generated by GitHub (see *About => Cite this repository*).
